@@ -18,42 +18,44 @@
 */
 
 #include "itemdeletejob.h"
-#include "itemmodifyjob.h"
+
+#include "collection.h"
+#include "collectionselectjob_p.h"
+#include "item.h"
 #include "job_p.h"
-#include "transactionsequence.h"
-#include "expungejob.h"
+#include "protocolhelper_p.h"
+
+#include <akonadi/private/imapparser_p.h>
+#include <akonadi/private/imapset_p.h>
+#include <akonadi/private/protocol_p.h>
+
+#include <KLocale>
 
 using namespace Akonadi;
 
 class Akonadi::ItemDeleteJobPrivate : public JobPrivate
 {
   public:
-    enum State {
-      Begin,
-      Store,
-      Expunge,
-      Commit
-    };
-
     ItemDeleteJobPrivate( ItemDeleteJob *parent )
       : JobPrivate( parent )
     {
     }
 
-    void jobDone( KJob* );
+    void selectResult( KJob *job );
 
     Q_DECLARE_PUBLIC( ItemDeleteJob )
 
-    Item mItem;
-    State mState;
+    Item::List mItems;
+    Collection mCollection;
 };
 
-void ItemDeleteJobPrivate::jobDone( KJob * job )
+void ItemDeleteJobPrivate::selectResult( KJob *job )
 {
-  Q_Q( ItemDeleteJob );
+  if ( job->error() )
+    return; // KCompositeJob takes care of errors
 
-  if ( !job->error() ) // error is already handled by KCompositeJob
-    q->emitResult();
+  const QByteArray command = newTag() + " " AKONADI_CMD_ITEMDELETE " 1:*\n";
+  writeData( command );
 }
 
 ItemDeleteJob::ItemDeleteJob( const Item & item, QObject * parent )
@@ -61,8 +63,21 @@ ItemDeleteJob::ItemDeleteJob( const Item & item, QObject * parent )
 {
   Q_D( ItemDeleteJob );
 
-  d->mItem = item;
-  d->mState = ItemDeleteJobPrivate::Begin;
+  d->mItems << item;
+}
+
+ItemDeleteJob::ItemDeleteJob(const Item::List& items, QObject* parent)
+  : Job( new ItemDeleteJobPrivate( this ), parent )
+{
+  Q_D( ItemDeleteJob );
+  d->mItems = items;
+}
+
+ItemDeleteJob::ItemDeleteJob(const Collection& collection, QObject* parent)
+  : Job( new ItemDeleteJobPrivate( this ), parent )
+{
+  Q_D( ItemDeleteJob );
+  d->mCollection = collection;
 }
 
 ItemDeleteJob::~ItemDeleteJob()
@@ -73,16 +88,23 @@ void ItemDeleteJob::doStart()
 {
   Q_D( ItemDeleteJob );
 
-  TransactionSequence  *transaction = new TransactionSequence( this );
-  connect( transaction, SIGNAL(result(KJob*)), SLOT(jobDone(KJob*)) );
-  addSubjob( transaction );
-
-  d->mItem.setFlag( "\\Deleted" );
-  ItemModifyJob* store = new ItemModifyJob( d->mItem, transaction );
-  store->disableRevisionCheck();
-
-  new ExpungeJob( transaction );
-  transaction->commit();
+  if ( !d->mItems.isEmpty() ) {
+    QByteArray command = d->newTag();
+    try {
+      command += ProtocolHelper::itemSetToByteArray( d->mItems, AKONADI_CMD_ITEMDELETE );
+    } catch ( const std::exception &e ) {
+      setError( Unknown );
+      setErrorText( QString::fromUtf8( e.what() ) );
+      emitResult();
+      return;
+    }
+    command += '\n';
+    d->writeData( command );
+  } else {
+    CollectionSelectJob *job = new CollectionSelectJob( d->mCollection, this );
+    connect( job, SIGNAL(result(KJob*)), SLOT(selectResult(KJob*)) );
+    addSubjob( job );
+  }
 }
 
 #include "itemdeletejob.moc"
