@@ -17,14 +17,21 @@
     02110-1301, USA.
 */
 
-#include "protocolhelper.h"
+#include "protocolhelper_p.h"
 
 #include "attributefactory.h"
-#include "imapparser_p.h"
+#include "collectionstatistics.h"
+#include "exception.h"
+#include <akonadi/private/imapparser_p.h>
+#include <akonadi/private/protocol_p.h>
 
 #include <QtCore/QVarLengthArray>
 
 #include <kdebug.h>
+#include <klocale.h>
+
+#include <boost/bind.hpp>
+#include <algorithm>
 
 using namespace Akonadi;
 
@@ -116,6 +123,18 @@ int ProtocolHelper::parseCollection(const QByteArray & data, Collection & collec
       for ( int j = 0; j < ct.size(); j++ )
         ct2 << QString::fromLatin1( ct[j] );
       collection.setContentMimeTypes( ct2 );
+    } else if ( key == "MESSAGES" ) {
+      CollectionStatistics s = collection.statistics();
+      s.setCount( value.toLongLong() );
+      collection.setStatistics( s );
+    } else if ( key == "UNSEEN" ) {
+      CollectionStatistics s = collection.statistics();
+      s.setUnreadCount( value.toLongLong() );
+      collection.setStatistics( s );
+    } else if ( key == "SIZE" ) {
+      CollectionStatistics s = collection.statistics();
+      s.setSize( value.toLongLong() );
+      collection.setStatistics( s );
     } else if ( key == "CACHEPOLICY" ) {
       CachePolicy policy;
       ProtocolHelper::parseCachePolicy( value, policy );
@@ -159,10 +178,10 @@ QByteArray ProtocolHelper::encodePartIdentifier(PartNamespace ns, const QByteArr
 
 QByteArray ProtocolHelper::decodePartIdentifier( const QByteArray &data, PartNamespace & ns )
 {
-  if ( data.startsWith( "PLD:" ) ) {
+  if ( data.startsWith( "PLD:" ) ) { //krazy:exclude=strings
     ns = PartPayload;
     return data.mid( 4 );
-  } else if ( data.startsWith( "ATR:" ) ) {
+  } else if ( data.startsWith( "ATR:" ) ) { //krazy:exclude=strings
     ns = PartAttribute;
     return data.mid( 4 );
   } else {
@@ -170,3 +189,41 @@ QByteArray ProtocolHelper::decodePartIdentifier( const QByteArray &data, PartNam
     return data;
   }
 }
+
+QByteArray ProtocolHelper::itemSetToByteArray( const Item::List &_items, const QByteArray &command )
+{
+  if ( _items.isEmpty() )
+    throw Exception( "No items specified" );
+
+  Item::List items( _items );
+
+  QByteArray rv;
+  std::sort( items.begin(), items.end(), boost::bind( &Item::id, _1 ) < boost::bind( &Item::id, _2 ) );
+  if ( items.first().isValid() ) {
+    // all items have a uid set
+    rv += " " AKONADI_CMD_UID " ";
+    rv += command;
+    rv += ' ';
+    QList<Item::Id>  uids;
+    foreach ( const Item &item, items )
+      uids << item.id();
+    ImapSet set;
+    set.add( uids );
+    rv += set.toImapSequenceSet();
+  } else {
+    // check if all items have a remote id
+    QList<QByteArray> rids;
+    foreach ( const Item &item, items ) {
+      if ( item.remoteId().isEmpty() )
+        throw Exception( i18n( "No remote identifier specified" ) );
+      rids << ImapParser::quote( item.remoteId().toUtf8() );
+    }
+
+    rv += " " AKONADI_CMD_RID " ";
+    rv += command;
+    rv += " (";
+    rv += ImapParser::join( rids, " " );
+    rv += ')';
+  }
+  return rv;
+}
