@@ -391,11 +391,11 @@ Event::List Calendar::sortEvents( Event::List *eventList,
 }
 
 Event::List Calendar::events( const QDate &date,
-                              const KDateTime::Spec &timespec,
+                              const KDateTime::Spec &timeSpec,
                               EventSortField sortField,
                               SortDirection sortDirection )
 {
-  Event::List el = rawEventsForDate( date, timespec, sortField, sortDirection );
+  Event::List el = rawEventsForDate( date, timeSpec, sortField, sortDirection );
   d->mFilter->apply( &el );
   return el;
 }
@@ -408,10 +408,10 @@ Event::List Calendar::events( const KDateTime &dt )
 }
 
 Event::List Calendar::events( const QDate &start, const QDate &end,
-                              const KDateTime::Spec &timespec,
+                              const KDateTime::Spec &timeSpec,
                               bool inclusive )
 {
-  Event::List el = rawEvents( start, end, timespec, inclusive );
+  Event::List el = rawEvents( start, end, timeSpec, inclusive );
   d->mFilter->apply( &el );
   return el;
 }
@@ -457,7 +457,11 @@ Incidence *Calendar::dissociateOccurrence( Incidence *incidence,
 
   Incidence *newInc = incidence->clone();
   newInc->recreate();
-  newInc->setRelatedTo( incidence );
+  // Do not call setRelatedTo() when dissociating recurring to-dos, otherwise the new to-do
+  // will appear as a child.  Originally, we planned to set a relation with reltype SIBLING
+  // when dissociating to-dos, but currently kcal only supports reltype PARENT.
+  // We can uncomment the following line when we support the PARENT reltype.
+  //newInc->setRelatedTo( incidence );
   Recurrence *recur = newInc->recurrence();
   if ( single ) {
     recur->clear();
